==> iam-0.8.2-sources.jar: software/amazon/awscdk/services/iam/cloudformation/GroupResource.java <==
package software.amazon.awscdk.services.iam.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.cloudformation.GroupResource")
public class GroupResource extends software.amazon.awscdk.Resource {
    protected GroupResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.iam.cloudformation.GroupResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::IAM::Group``.
     * @param parent the ``cdk.Construct`` this ``GroupResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``GroupResource``
     */
    public GroupResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.iam.cloudformation.GroupResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::IAM::Group``.
     * @param parent the ``cdk.Construct`` this ``GroupResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public GroupResource(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
    /**
     * @cloudformation_attribute Arn
     */
    public software.amazon.awscdk.services.iam.GroupArn getGroupArn() {
        return this.jsiiGet("groupArn", software.amazon.awscdk.services.iam.GroupArn.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html
     */
    public static interface PolicyProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``GroupResource.PolicyProperty.PolicyDocument``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
         */
        java.lang.Object getPolicyDocument();
        /**
         * ``GroupResource.PolicyProperty.PolicyDocument``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
         */
        void setPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value);
        /**
         * ``GroupResource.PolicyProperty.PolicyDocument``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
         */
        void setPolicyDocument(final software.amazon.awscdk.Token value);
        /**
         * ``GroupResource.PolicyProperty.PolicyName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
         */
        java.lang.Object getPolicyName();
        /**
         * ``GroupResource.PolicyProperty.PolicyName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
         */
        void setPolicyName(final java.lang.String value);
        /**
         * ``GroupResource.PolicyProperty.PolicyName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
         */
        void setPolicyName(final software.amazon.awscdk.Token value);

        // ==================================================================
        // Builder
        // ==================================================================

        static Builder builder() {
            return new Builder();
        }
        /**
         * A fluent step builder class for {@link PolicyProperty}.
         * The {@link Build#build()} method will be available once all required properties are fulfilled.
         */
        final class Builder {
            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            public PolicyNameStep withPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                return new FullBuilder().withPolicyDocument(value);
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            public PolicyNameStep withPolicyDocument(final software.amazon.awscdk.Token value) {
                return new FullBuilder().withPolicyDocument(value);
            }

            public interface PolicyNameStep {
                /**
                 * ``GroupResource.PolicyProperty.PolicyName``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
                 */
                Build withPolicyName(final java.lang.String value);
                /**
                 * ``GroupResource.PolicyProperty.PolicyName``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
                 */
                Build withPolicyName(final software.amazon.awscdk.Token value);
            }

            public interface Build {
                /**
                 * @return a new {@link PolicyProperty} object, initialized with the values set on this builder.
                 */
                PolicyProperty build();
            }

            final class FullBuilder implements PolicyNameStep, Build {

                private Jsii$Pojo instance = new Jsii$Pojo();

                /**
                 * ``GroupResource.PolicyProperty.PolicyDocument``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
                 */
                public PolicyNameStep withPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                    java.util.Objects.requireNonNull(value, "PolicyProperty#policyDocument is required");
                    this.instance._policyDocument = value;
                    return this;
                }
                /**
                 * ``GroupResource.PolicyProperty.PolicyDocument``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
                 */
                public PolicyNameStep withPolicyDocument(final software.amazon.awscdk.Token value) {
                    java.util.Objects.requireNonNull(value, "PolicyProperty#policyDocument is required");
                    this.instance._policyDocument = value;
                    return this;
                }
                /**
                 * ``GroupResource.PolicyProperty.PolicyName``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
                 */
                public Build withPolicyName(final java.lang.String value) {
                    java.util.Objects.requireNonNull(value, "PolicyProperty#policyName is required");
                    this.instance._policyName = value;
                    return this;
                }
                /**
                 * ``GroupResource.PolicyProperty.PolicyName``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
                 */
                public Build withPolicyName(final software.amazon.awscdk.Token value) {
                    java.util.Objects.requireNonNull(value, "PolicyProperty#policyName is required");
                    this.instance._policyName = value;
                    return this;
                }
                public PolicyProperty build() {
                    PolicyProperty result = this.instance;
                    this.instance = new Jsii$Pojo();
                    return result;
                }
            }
        }

        /**
         * A PoJo (plain-old-java-object) class that implements {@link PolicyProperty}.
         */
        final class Jsii$Pojo implements PolicyProperty {

            /**
             * Constructor used by builders.
             */
            protected Jsii$Pojo() { }


            protected java.lang.Object _policyDocument;

            public java.lang.Object getPolicyDocument() {
                return this._policyDocument;
            }
            public void setPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                this._policyDocument = value;
            }
            public void setPolicyDocument(final software.amazon.awscdk.Token value) {
                this._policyDocument = value;
            }

            protected java.lang.Object _policyName;

            public java.lang.Object getPolicyName() {
                return this._policyName;
            }
            public void setPolicyName(final java.lang.String value) {
                this._policyName = value;
            }
            public void setPolicyName(final software.amazon.awscdk.Token value) {
                this._policyName = value;
            }
        }

        /**
         * A proxy class which for javascript object literal which adhere to this interface.
         */
        class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.iam.cloudformation.GroupResource.PolicyProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            public java.lang.Object getPolicyDocument() {
                return this.jsiiGet("policyDocument", java.lang.Object.class);
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            public void setPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                this.jsiiSet("policyDocument", java.util.Objects.requireNonNull(value, "policyDocument is required"));
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            public void setPolicyDocument(final software.amazon.awscdk.Token value) {
                this.jsiiSet("policyDocument", java.util.Objects.requireNonNull(value, "policyDocument is required"));
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
             */
            public java.lang.Object getPolicyName() {
                return this.jsiiGet("policyName", java.lang.Object.class);
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
             */
            public void setPolicyName(final java.lang.String value) {
                this.jsiiSet("policyName", java.util.Objects.requireNonNull(value, "policyName is required"));
            }
            /**
             * ``GroupResource.PolicyProperty.PolicyName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
             */
            public void setPolicyName(final software.amazon.awscdk.Token value) {
                this.jsiiSet("policyName", java.util.Objects.requireNonNull(value, "policyName is required"));
            }
        }
    }
}

==> iam-0.9.0-sources.jar: software/amazon/awscdk/services/iam/cloudformation/GroupResource.java <==
package software.amazon.awscdk.services.iam.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-group.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:54:34.630Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.cloudformation.GroupResource")
public class GroupResource extends software.amazon.awscdk.Resource {
    protected GroupResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.iam.cloudformation.GroupResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::IAM::Group``.
     * @param parent the ``cdk.Construct`` this ``GroupResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``GroupResource``
     */
    public GroupResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.iam.cloudformation.GroupResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::IAM::Group``.
     * @param parent the ``cdk.Construct`` this ``GroupResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public GroupResource(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute Arn
     */
    public software.amazon.awscdk.services.iam.GroupArn getGroupArn() {
        return this.jsiiGet("groupArn", software.amazon.awscdk.services.iam.GroupArn.class);
    }

    public software.amazon.awscdk.services.iam.GroupName getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.iam.GroupName.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html
     */
    public static interface PolicyProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``GroupResource.PolicyProperty.PolicyDocument``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
         */
        java.lang.Object getPolicyDocument();
        /**
         * ``GroupResource.PolicyProperty.PolicyDocument``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
         */
        void setPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value);
        /**
         * ``GroupResource.PolicyProperty.PolicyDocument``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
         */
        void setPolicyDocument(final software.amazon.awscdk.CloudFormationToken value);
        /**
         * ``GroupResource.PolicyProperty.PolicyName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
         */
        java.lang.Object getPolicyName();
        /**
         * ``GroupResource.PolicyProperty.PolicyName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
         */
        void setPolicyName(final java.lang.String value);
        /**
         * ``GroupResource.PolicyProperty.PolicyName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
         */
        void setPolicyName(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link PolicyProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link PolicyProperty}
         */
        final class Builder {
            private java.lang.Object _policyDocument;
            private java.lang.Object _policyName;

            /**
             * Sets the value of PolicyDocument
             * @param value ``GroupResource.PolicyProperty.PolicyDocument``
             * @return {@code this}
             */
            public Builder withPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                this._policyDocument = java.util.Objects.requireNonNull(value, "policyDocument is required");
                return this;
            }
            /**
             * Sets the value of PolicyDocument
             * @param value ``GroupResource.PolicyProperty.PolicyDocument``
             * @return {@code this}
             */
            public Builder withPolicyDocument(final software.amazon.awscdk.CloudFormationToken value) {
                this._policyDocument = java.util.Objects.requireNonNull(value, "policyDocument is required");
                return this;
            }
            /**
             * Sets the value of PolicyName
             * @param value ``GroupResource.PolicyProperty.PolicyName``
             * @return {@code this}
             */
            public Builder withPolicyName(final java.lang.String value) {
                this._policyName = java.util.Objects.requireNonNull(value, "policyName is required");
                return this;
            }
            /**
             * Sets the value of PolicyName
             * @param value ``GroupResource.PolicyProperty.PolicyName``
             * @return {@code this}
             */
            public Builder withPolicyName(final software.amazon.awscdk.CloudFormationToken value) {
                this._policyName = java.util.Objects.requireNonNull(value, "policyName is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link PolicyProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public PolicyProperty build() {
                return new PolicyProperty() {
                    private java.lang.Object $policyDocument = java.util.Objects.requireNonNull(_policyDocument, "policyDocument is required");
                    private java.lang.Object $policyName = java.util.Objects.requireNonNull(_policyName, "policyName is required");

                    @Override
                    public java.lang.Object getPolicyDocument() {
                        return this.$policyDocument;
                    }

                    @Override
                    public void setPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                        this.$policyDocument = java.util.Objects.requireNonNull(value, "policyDocument is required");
                    }

                    @Override
                    public void setPolicyDocument(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$policyDocument = java.util.Objects.requireNonNull(value, "policyDocument is required");
                    }

                    @Override
                    public java.lang.Object getPolicyName() {
                        return this.$policyName;
                    }

                    @Override
                    public void setPolicyName(final java.lang.String value) {
                        this.$policyName = java.util.Objects.requireNonNull(value, "policyName is required");
                    }

                    @Override
                    public void setPolicyName(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$policyName = java.util.Objects.requireNonNull(value, "policyName is required");
                    }

                };
            }
        }

        /**
         * A proxy class which for javascript object literal which adhere to this interface.
         */
        final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.iam.cloudformation.GroupResource.PolicyProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            @Override
            public java.lang.Object getPolicyDocument() {
                return this.jsiiGet("policyDocument", java.lang.Object.class);
            }

            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            @Override
            public void setPolicyDocument(final com.fasterxml.jackson.databind.node.ObjectNode value) {
                this.jsiiSet("policyDocument", java.util.Objects.requireNonNull(value, "policyDocument is required"));
            }

            /**
             * ``GroupResource.PolicyProperty.PolicyDocument``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policydocument
             */
            @Override
            public void setPolicyDocument(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("policyDocument", java.util.Objects.requireNonNull(value, "policyDocument is required"));
            }

            /**
             * ``GroupResource.PolicyProperty.PolicyName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
             */
            @Override
            public java.lang.Object getPolicyName() {
                return this.jsiiGet("policyName", java.lang.Object.class);
            }

            /**
             * ``GroupResource.PolicyProperty.PolicyName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
             */
            @Override
            public void setPolicyName(final java.lang.String value) {
                this.jsiiSet("policyName", java.util.Objects.requireNonNull(value, "policyName is required"));
            }

            /**
             * ``GroupResource.PolicyProperty.PolicyName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-iam-policy.html#cfn-iam-policies-policyname
             */
            @Override
            public void setPolicyName(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("policyName", java.util.Objects.requireNonNull(value, "policyName is required"));
            }
        }
    }
}
